==> jc-1.4.0.tar.gz: soot/tagkit/AttributeValueException.h <==
// public class soot.tagkit.AttributeValueException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class bb48366d37ab1bd9 soot_tagkit_AttributeValueException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_soot_tagkit_AttributeValueException_H_
#define _JC_soot_tagkit_AttributeValueException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_tagkit_AttributeValueException$sub_refs	_jc_soot_tagkit_AttributeValueException$sub_refs;
typedef struct _jc_soot_tagkit_AttributeValueException$sub_nonrefs	_jc_soot_tagkit_AttributeValueException$sub_nonrefs;
typedef struct _jc_soot_tagkit_AttributeValueException$refs	_jc_soot_tagkit_AttributeValueException$refs;
typedef struct _jc_soot_tagkit_AttributeValueException$nonrefs	_jc_soot_tagkit_AttributeValueException$nonrefs;
typedef struct _jc_soot_tagkit_AttributeValueException$object	_jc_soot_tagkit_AttributeValueException$object;

typedef const struct _jc_soot_tagkit_AttributeValueException$vmethods	_jc_soot_tagkit_AttributeValueException$vmethods;
typedef const struct _jc_soot_tagkit_AttributeValueException$vtable	_jc_soot_tagkit_AttributeValueException$vtable;
typedef const struct _jc_soot_tagkit_AttributeValueException$vtype	_jc_soot_tagkit_AttributeValueException$vtype;

// Constructors
extern void _jc_soot_tagkit_AttributeValueException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_tagkit_AttributeValueException$object *);

// Virtual methods structure
struct _jc_soot_tagkit_AttributeValueException$vmethods {
};

// Vtable
struct _jc_soot_tagkit_AttributeValueException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_soot_tagkit_AttributeValueException$vmethods	soot_tagkit_AttributeValueException;
};

// Vtype
struct _jc_soot_tagkit_AttributeValueException$vtype {
	_jc_type			type;
	_jc_soot_tagkit_AttributeValueException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_AttributeValueException$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_AttributeValueException$refs {
    _jc_soot_tagkit_AttributeValueException$sub_refs	soot_tagkit_AttributeValueException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_AttributeValueException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_AttributeValueException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_soot_tagkit_AttributeValueException$sub_nonrefs	soot_tagkit_AttributeValueException;
};

// Object instance structure
struct _jc_soot_tagkit_AttributeValueException$object {
	_jc_soot_tagkit_AttributeValueException$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_AttributeValueException$vtype	*vtype;
	_jc_soot_tagkit_AttributeValueException$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_AttributeValueException$vtype _jc_soot_tagkit_AttributeValueException$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_AttributeValueException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_AttributeValueException$class_object;

#endif	/* _JC_soot_tagkit_AttributeValueException_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/AttributeValueException.h <==
// public class soot.tagkit.AttributeValueException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class bb48366d37ab1bd9 soot_tagkit_AttributeValueException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_soot_tagkit_AttributeValueException_H_
#define _JC_soot_tagkit_AttributeValueException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_tagkit_AttributeValueException$sub_refs	_jc_soot_tagkit_AttributeValueException$sub_refs;
typedef struct _jc_soot_tagkit_AttributeValueException$sub_nonrefs	_jc_soot_tagkit_AttributeValueException$sub_nonrefs;
typedef struct _jc_soot_tagkit_AttributeValueException$refs	_jc_soot_tagkit_AttributeValueException$refs;
typedef struct _jc_soot_tagkit_AttributeValueException$nonrefs	_jc_soot_tagkit_AttributeValueException$nonrefs;
typedef struct _jc_soot_tagkit_AttributeValueException$object	_jc_soot_tagkit_AttributeValueException$object;

typedef const struct _jc_soot_tagkit_AttributeValueException$vmethods	_jc_soot_tagkit_AttributeValueException$vmethods;
typedef const struct _jc_soot_tagkit_AttributeValueException$vtable	_jc_soot_tagkit_AttributeValueException$vtable;
typedef const struct _jc_soot_tagkit_AttributeValueException$vtype	_jc_soot_tagkit_AttributeValueException$vtype;

// Constructors
extern void _jc_soot_tagkit_AttributeValueException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_tagkit_AttributeValueException$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_tagkit_AttributeValueException$vmethods {
};

// Vtable
struct _jc_soot_tagkit_AttributeValueException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_soot_tagkit_AttributeValueException$vmethods	soot_tagkit_AttributeValueException;
};

// Vtype
struct _jc_soot_tagkit_AttributeValueException$vtype {
	_jc_type			type;
	_jc_soot_tagkit_AttributeValueException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_AttributeValueException$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_AttributeValueException$refs {
    _jc_soot_tagkit_AttributeValueException$sub_refs	soot_tagkit_AttributeValueException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_AttributeValueException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_AttributeValueException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_soot_tagkit_AttributeValueException$sub_nonrefs	soot_tagkit_AttributeValueException;
};

// Object instance structure
struct _jc_soot_tagkit_AttributeValueException$object {
	_jc_soot_tagkit_AttributeValueException$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_AttributeValueException$vtype	*vtype;
	_jc_soot_tagkit_AttributeValueException$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_AttributeValueException$vtype _jc_soot_tagkit_AttributeValueException$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_AttributeValueException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_AttributeValueException$class_object;

#endif	/* _JC_soot_tagkit_AttributeValueException_H_ */
